@@ -1,6 +1,7 @@
 pub mod context;
 pub use context::{
-    ExecutionArtifact, ExecutionArtifacts, ExecutionContext, ExecutionStrategy, TestParameters, ChildProcessComponentArgs, ChildProcessComponentMetaArgs
+    ChildProcessComponentArgs, ChildProcessComponentMetaArgs, ExecutionArtifact,
+    ExecutionArtifacts, ExecutionContext, ExecutionStrategy, TestParameters,
 };
 
 pub mod delegates;
@@ -32,4 +33,4 @@ pub enum Component<TParameters> {
     Test(Test<TParameters>),
     Setup(BookEnd<TParameters>),
     TearDown(BookEnd<TParameters>),
-}
\ No newline at end of file
+}
